@@ -367,7 +367,7 @@ class YAML:
         if not hasattr(stream, 'read') and hasattr(stream, 'open'):
             # pathlib.Path() instance
             with stream.open('rb') as fp:
-                return self.load(fp)
+                return self.compose(fp)
         constructor, parser = self.get_constructor_parser(stream)
         try:
             return constructor.composer.get_single_node()
@@ -444,7 +444,7 @@ class YAML:
                 pass
 
     def load_all(self, stream):  # *, skip=None):
-        # type: (Union[Path, StreamTextType], Any) -> Any
+        # type: (Union[Path, StreamTextType]) -> Any
         if not hasattr(stream, 'read') and hasattr(stream, 'open'):
             # pathlib.Path() instance
             with stream.open('r') as fp:
@@ -516,6 +516,7 @@ class YAML:
         return self.constructor, self.parser
 
     def emit(self, events, stream):
+        # type: (Any, Any) -> None
         """
         Emit YAML parsing events into a stream.
         If stream is None, return the produced string instead.
@@ -573,7 +574,7 @@ class YAML:
             return self.dump_all([data], stream, transform=transform)
 
     def dump_all(self, documents, stream, *, transform=None):
-        # type: (Any, Union[Path, StreamType], Any, Any) -> Any
+        # type: (Any, Union[Path, StreamType], Any) -> Any
         if self._context_manager:
             raise NotImplementedError
         self._output = stream
@@ -585,7 +586,7 @@ class YAML:
         self._context_manager = None
 
     def Xdump_all(self, documents, stream, *, transform=None):
-        # type: (Any, Union[Path, StreamType], Any, Any) -> Any
+        # type: (Any, Any, Any) -> Any
         """
         Serialize a sequence of Python objects into a YAML stream.
         """
@@ -980,6 +981,7 @@ def yaml_object(yml):
 
 ########################################################################################
 def warn_deprecation(fun, method, arg=''):
+    # type: (Any, Any, str) -> None
     from ruamel.yaml.compat import _F
 
     warnings.warn(
@@ -992,6 +994,8 @@ def warn_deprecation(fun, method, arg=''):
         PendingDeprecationWarning,  # this will show when testing with pytest/tox
         stacklevel=3,
     )
+
+
 ########################################################################################
 
 
@@ -1053,7 +1057,7 @@ def compose_all(stream, Loader=Loader):
 
 
 def load(stream, Loader=None, version=None, preserve_quotes=None):
-    # type: (StreamTextType, Any, Optional[VersionType], Any) -> Any
+    # type: (Any, Any, Any, Any) -> Any
     """
     Parse the first YAML document in a stream
     and produce the corresponding Python object.
@@ -1062,7 +1066,7 @@ def load(stream, Loader=None, version=None, preserve_quotes=None):
     if Loader is None:
         warnings.warn(UnsafeLoaderWarning.text, UnsafeLoaderWarning, stacklevel=2)
         Loader = UnsafeLoader
-    loader = Loader(stream, version, preserve_quotes=preserve_quotes)
+    loader = Loader(stream, version, preserve_quotes=preserve_quotes)  # type: Any
     try:
         return loader._constructor.get_single_data()
     finally:
@@ -1078,7 +1082,7 @@ def load(stream, Loader=None, version=None, preserve_quotes=None):
 
 
 def load_all(stream, Loader=None, version=None, preserve_quotes=None):
-    # type: (Optional[StreamTextType], Any, Optional[VersionType], Optional[bool]) -> Any  # NOQA
+    # type: (Any, Any, Any, Any) -> Any  # NOQA
     """
     Parse all YAML documents in a stream
     and produce corresponding Python objects.
@@ -1087,7 +1091,7 @@ def load_all(stream, Loader=None, version=None, preserve_quotes=None):
     if Loader is None:
         warnings.warn(UnsafeLoaderWarning.text, UnsafeLoaderWarning, stacklevel=2)
         Loader = UnsafeLoader
-    loader = Loader(stream, version, preserve_quotes=preserve_quotes)
+    loader = Loader(stream, version, preserve_quotes=preserve_quotes)  # type: Any
     try:
         while loader._constructor.check_data():
             yield loader._constructor.get_data()
@@ -1277,7 +1281,7 @@ def dump_all(
     top_level_colon_align=None,
     prefix_colon=None,
 ):
-    # type: (Any, Optional[StreamType], Any, Any, Any, Optional[bool], Optional[int], Optional[int], Optional[bool], Any, Any, Optional[bool], Optional[bool], Any, Any, Any, Any, Any) -> Optional[str]   # NOQA
+    # type: (Any, Optional[StreamType], Any, Any, Any, Optional[bool], Optional[int], Optional[int], Optional[bool], Any, Any, Optional[bool], Optional[bool], Any, Any, Any, Any, Any) -> Any  # NOQA
     """
     Serialize a sequence of Python objects into a YAML stream.
     If stream is None, return the produced string instead.
@@ -1348,7 +1352,7 @@ def dump(
     tags=None,
     block_seq_indent=None,
 ):
-    # type: (Any, Optional[StreamType], Any, Any, Any, Optional[bool], Optional[int], Optional[int], Optional[bool], Any, Any, Optional[bool], Optional[bool], Optional[VersionType], Any, Any) -> Optional[str]   # NOQA
+    # type: (Any, Optional[StreamType], Any, Any, Any, Optional[bool], Optional[int], Optional[int], Optional[bool], Any, Any, Optional[bool], Optional[bool], Optional[VersionType], Any, Any) -> Optional[Any]   # NOQA
     """
     Serialize a Python object into a YAML stream.
     If stream is None, return the produced string instead.
@@ -1378,7 +1382,7 @@ def dump(
 
 
 def safe_dump_all(documents, stream=None, **kwds):
-    # type: (Any, Optional[StreamType], Any) -> Optional[str]
+    # type: (Any, Optional[StreamType], Any) -> Optional[Any]
     """
     Serialize a sequence of Python objects into a YAML stream.
     Produce only basic YAML tags.
@@ -1389,7 +1393,7 @@ def safe_dump_all(documents, stream=None, **kwds):
 
 
 def safe_dump(data, stream=None, **kwds):
-    # type: (Any, Optional[StreamType], Any) -> Optional[str]
+    # type: (Any, Optional[StreamType], Any) -> Optional[Any]
     """
     Serialize a Python object into a YAML stream.
     Produce only basic YAML tags.
@@ -1419,7 +1423,7 @@ def round_trip_dump(
     top_level_colon_align=None,
     prefix_colon=None,
 ):
-    # type: (Any, Optional[StreamType], Any, Any, Any, Optional[bool], Optional[int], Optional[int], Optional[bool], Any, Any, Optional[bool], Optional[bool], Optional[VersionType], Any, Any, Any, Any) -> Optional[str]   # NOQA
+    # type: (Any, Optional[StreamType], Any, Any, Any, Optional[bool], Optional[int], Optional[int], Optional[bool], Any, Any, Optional[bool], Optional[bool], Optional[VersionType], Any, Any, Any, Any) -> Optional[Any]   # NOQA
     allow_unicode = True if allow_unicode is None else allow_unicode
     warn_deprecation('round_trip_dump', 'dump')
     return dump_all(
