@@ -2,7 +2,7 @@
 
 from ruamel.yaml.error import *  # NOQA
 from ruamel.yaml.nodes import *  # NOQA
-from ruamel.yaml.compat import ordereddict  # type: ignore
+from ruamel.yaml.compat import ordereddict
 from ruamel.yaml.compat import _F, nprint, nprintf  # NOQA
 from ruamel.yaml.scalarstring import (
     LiteralScalarString,
@@ -26,6 +26,7 @@ from ruamel.yaml.scalarint import ScalarInt, BinaryInt, OctalInt, HexInt, HexCap
 from ruamel.yaml.scalarfloat import ScalarFloat
 from ruamel.yaml.scalarbool import ScalarBoolean
 from ruamel.yaml.timestamp import TimeStamp
+from ruamel.yaml.anchor import Anchor
 
 import datetime
 import sys
@@ -253,7 +254,8 @@ class SafeRepresenter(BaseRepresenter):
         if hasattr(base64, 'encodebytes'):
             data = base64.encodebytes(data).decode('ascii')
         else:
-            data = base64.encodestring(data).decode('ascii')
+            # check py2 only?
+            data = base64.encodestring(data).decode('ascii')  # type: ignore
         return self.represent_scalar('tag:yaml.org,2002:binary', data, style='|')
 
     def represent_bool(self, data, anchor=None):
@@ -439,8 +441,8 @@ class Representer(SafeRepresenter):
         # !!python/object/apply node.
 
         cls = type(data)
-        if cls in copyreg.dispatch_table:
-            reduce = copyreg.dispatch_table[cls](data)
+        if cls in copyreg.dispatch_table:  # type: ignore
+            reduce = copyreg.dispatch_table[cls](data)  # type: ignore
         elif hasattr(data, '__reduce_ex__'):
             reduce = data.__reduce_ex__(2)
         elif hasattr(data, '__reduce__'):
@@ -1079,6 +1081,18 @@ class RoundTripRepresenter(SafeRepresenter):
             anchor = None
         return SafeRepresenter.represent_bool(self, data, anchor=anchor)
 
+    def represent_yaml_object(self, tag, data, cls, flow_style=None):
+        # type: (Any, Any, Any, Optional[Any]) -> Any
+        if hasattr(data, '__getstate__'):
+            state = data.__getstate__()
+        else:
+            state = data.__dict__.copy()
+        anchor = state.pop(Anchor.attrib, None)
+        res = self.represent_mapping(tag, state, flow_style=flow_style)
+        if anchor is not None:
+            res.anchor = anchor
+        return res
+
 
 RoundTripRepresenter.add_representer(type(None), RoundTripRepresenter.represent_none)
 
